pub enum Token {
Show 68 variants
OpBracket,
ClBracket,
OpBrace,
ClBrace,
OpParen,
ClParen,
OpBlockComment,
ClBlockComment,
KwA,
KwAF,
KwB,
KwBC,
KwBitStruct,
KwBreak,
KwC,
KwConst,
KwContinue,
KwD,
KwDE,
KwE,
KwElse,
KwF,
KwFalse,
KwFn,
KwH,
KwHL,
KwIf,
KwL,
KwLet,
KwLoop,
KwMut,
KwNC,
KwNZ,
KwReturn,
KwSP,
KwStatic,
KwStruct,
KwTrue,
KwZ,
Ident,
NumLit,
LineComment,
Newline,
Tilde,
Backtick,
Exclamation,
AtSign,
Hash,
Dollar,
Percent,
Caret,
Ampersand,
Asterisk,
Minus,
Plus,
Equal,
Pipe,
Backslash,
Colon,
Semicolon,
Quote,
LessThan,
Comma,
GreaterThan,
Period,
Question,
Slash,
TokenError,
}Variants
OpBracket
ClBracket
OpBrace
ClBrace
OpParen
ClParen
OpBlockComment
ClBlockComment
KwA
KwAF
KwB
KwBC
KwBitStruct
KwBreak
KwC
KwConst
KwContinue
KwD
KwDE
KwE
KwElse
KwF
KwFalse
KwFn
KwH
KwHL
KwIf
KwL
KwLet
KwLoop
KwMut
KwNC
KwNZ
KwReturn
KwSP
KwStatic
KwStruct
KwTrue
KwZ
Ident
NumLit
LineComment
Newline
Tilde
Backtick
Exclamation
AtSign
Hash
Dollar
Percent
Caret
Ampersand
Asterisk
Minus
Plus
Equal
Pipe
Backslash
Colon
Semicolon
Quote
LessThan
Comma
GreaterThan
Period
Question
Slash
TokenError
Implementations
Sourceimpl Token
impl Token
Sourcepub fn lexer<'source>(
source: &'source <Self as Logos<'_>>::Source,
) -> Lexer<'source, Self> ⓘ
pub fn lexer<'source>( source: &'source <Self as Logos<'_>>::Source, ) -> Lexer<'source, Self> ⓘ
Allows the lexer method to be called without needing to import the trait.
Sourcepub fn lexer_with_extras<'source>(
source: &'source <Self as Logos<'_>>::Source,
extras: <Self as Logos<'_>>::Extras,
) -> Lexer<'source, Self> ⓘ
pub fn lexer_with_extras<'source>( source: &'source <Self as Logos<'_>>::Source, extras: <Self as Logos<'_>>::Extras, ) -> Lexer<'source, Self> ⓘ
Allows the lexer_with_extras method to be called without needing to import the trait.